@@ -42,15 +42,18 @@ module Safe(
     maximumDef, maximumMay, maximumNote,
     foldr1Def, foldr1May, foldr1Note,
     foldl1Def, foldl1May, foldl1Note,
+    foldl1Def', foldl1May', foldl1Note',
     fromJustDef, fromJustNote,
     assertNote,
     at, atDef, atMay, atNote,
     readDef, readMay, readNote,
     lookupJust, lookupJustDef, lookupJustNote,
+    findJust, findJustDef, findJustNote,
     abort
     ) where
 
 
+import Data.List
 import Data.Maybe
 
 
@@ -171,6 +174,16 @@ foldl1Note :: String -> (a -> a -> a) -> [a] -> a
 foldl1Note note f = liftNote (foldl1 f) null "foldl1 []" note
 
 
+foldl1Def'  :: a -> (a -> a -> a) -> [a] -> a
+foldl1Def' def f = liftDef (foldl1' f) null def
+
+foldl1May'  :: (a -> a -> a) -> [a] -> Maybe a
+foldl1May' f = liftMay (foldl1' f) null
+
+foldl1Note' :: String -> (a -> a -> a) -> [a] -> a
+foldl1Note' note f = liftNote (foldl1' f) null "foldl1' []" note
+
+
 -- | See fromMaybe
 fromJustDef :: a -> Maybe a -> a
 fromJustDef  = liftDef fromJust isNothing
@@ -242,6 +255,21 @@ lookupJustNote msg key lst = case lookup key lst of
 
 
 
+-- |
+-- > findJust op = fromJust . find op
+findJust :: (a -> Bool) -> [a] -> a
+findJust op = fromJustNote "findJust, item not found" . find op
+
+findJustDef :: a -> (a -> Bool) -> [a] -> a
+findJustDef def op lst = fromMaybe def (find op lst)
+
+findJustNote :: String -> (a -> Bool) -> [a] -> a
+findJustNote msg op lst = case find op lst of
+                               Nothing -> error $ "Safe.findJust: element not found, " ++ msg
+                               Just x -> x
+
+
+
 -- | Exactly the same as @error@. Use this for instances where the program
 --   has decided to exit because of invalid user input, or the user pressed
 --   quit etc. This allows @error@ to be reserved for genuine coding mistakes.
